/// <reference types="node" />
import * as Long from 'long';
/**
 * Output write helper for {@link IdentifiedDataSerializable} objects.
 */
export interface DataOutput {
    clear(): void;
    isBigEndian(): boolean;
    position(newPosition?: number): number;
    toBuffer(): Buffer;
    write(byte: number | Buffer): void;
    writeBoolean(val: boolean): void;
    writeBooleanArray(val: boolean[]): void;
    writeByte(byte: number): void;
    writeByteArray(bytes: Buffer): void;
    writeChar(char: string): void;
    writeCharArray(chars: string[]): void;
    writeChars(chars: string): void;
    writeDouble(double: number): void;
    writeDoubleArray(doubles: number[]): void;
    writeFloat(float: number): void;
    writeFloatArray(floats: number[]): void;
    writeInt(int: number): void;
    writeIntBE(int: number): void;
    writeIntArray(ints: number[]): void;
    writeLong(long: Long): void;
    writeLongArray(longs: Long[]): void;
    writeObject(object: any): void;
    writeShort(short: number): void;
    writeShortArray(shorts: number[]): void;
    /** @deprecated since version 4.2.
     *  This method will be removed in next major version. Please use {@link writeString} instead.
     */
    writeUTF(val: string): void;
    /** @deprecated since version 4.2.
     *  This method will be removed in next major version. Please use {@link writeStringArray} instead.
     */
    writeUTFArray(val: string[]): void;
    writeString(val: string): void;
    writeStringArray(val: string[]): void;
    writeZeroBytes(count: number): void;
}
/**
 * Input read helper for {@link IdentifiedDataSerializable} objects.
 */
export interface DataInput {
    isBigEndian(): boolean;
    position(newPosition?: number): number;
    read(pos?: number): number;
    readBoolean(pos?: number): boolean;
    readBooleanArray(pos?: number): boolean[];
    readByte(pos?: number): number;
    readByteArray(pos?: number): Buffer;
    readChar(pos?: number): string;
    readCharArray(pos?: number): string[];
    readDouble(pos?: number): number;
    readDoubleArray(pos?: number): number[];
    readFloat(pos?: number): number;
    readFloatArray(pos?: number): number[];
    readInt(pos?: number): number;
    readIntArray(pos?: number): number[];
    readLong(pos?: number): Long;
    readLongArray(pos?: number): Long[];
    readObject(): any;
    readShort(pos?: number): number;
    readShortArray(pos?: number): number[];
    readUnsignedByte(pos?: number): number;
    readUnsignedShort(pos?: number): number;
    /** @deprecated since version 4.2.
     *  This method will be removed in next major version. Please use {@link readString} instead.
     */
    readUTF(pos?: number): string;
    /** @deprecated since version 4.2.
     *  This method will be removed in next major version. Please use {@link readStringArray} instead.
     */
    readUTFArray(pos?: number): string[];
    readString(pos?: number): string;
    readStringArray(pos?: number): string[];
    reset(): void;
    skipBytes(count: number): void;
    available(): number;
}
